==> haskell-hspec-wai-0.9.0-86-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai
version: 0.9.0
id: hspec-wai-0.9.0-1bnGIHOiCLAKgJ9m8FFOWm
key: hspec-wai-0.9.0-1bnGIHOiCLAKgJ9m8FFOWm
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2015 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Experimental Hspec support for testing WAI applications
description:
    Experimental Hspec support for testing WAI applications
category: Testing
abi: ce8f82438682edbb03dfae438d7215d1
exposed: True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck
hidden-modules: Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-wai-0.9.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-wai-0.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hspec-wai-0.9.0
hs-libraries: HShspec-wai-0.9.0-1bnGIHOiCLAKgJ9m8FFOWm
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    hspec-core-2.5.4-8fjXebY7ghD347PVCe5iJm
    hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk
    http-types-0.12.1-5poL28rXupOCvN0z3OZHGo text-1.2.3.0
    transformers-0.5.5.0 wai-3.2.1.2-DAUrzKGFFJQ7O9zcpubE0P
    wai-extra-3.0.22.1-JYgmFErczB2VA6tpAlpln
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             hspec-core-2.5.4-8fjXebY7ghD347PVCe5iJm=b4e9ef6ad86fe730e79ae4d33a01c7a7
             hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk=b75babfddd4aa9a267b9714ea3ac9e19
             http-types-0.12.1-5poL28rXupOCvN0z3OZHGo=e6a28b7de312f3215e1e4e51d35f93a2
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             wai-3.2.1.2-DAUrzKGFFJQ7O9zcpubE0P=10362ca7ed2c4d5a782af4c0ab83118b
             wai-extra-3.0.22.1-JYgmFErczB2VA6tpAlpln=bf4e21b03a795ee3730f7e7f6866162a
haddock-interfaces: /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-0.9.0-92-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-wai.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-wai
version: 0.9.0
id: hspec-wai-0.9.0-9vBjdefcesqDA0TplrrZF8
key: hspec-wai-0.9.0-9vBjdefcesqDA0TplrrZF8
license: MIT
copyright: (c) 2012-2014 Fujimura Daisuke,
           (c) 2014-2015 Simon Hengel
maintainer: Fujimura Daisuke <me@fujimuradaisuke.com>,
            Simon Hengel <sol@typeful.net>
author: Fujimura Daisuke <me@fujimuradaisuke.com>,
        Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-wai#readme
synopsis: Experimental Hspec support for testing WAI applications
description:
    Experimental Hspec support for testing WAI applications
category: Testing
abi: 5117c27d491bd9125b4f8dba3cc14e48
exposed: True
exposed-modules:
    Test.Hspec.Wai Test.Hspec.Wai.Internal Test.Hspec.Wai.Matcher
    Test.Hspec.Wai.QuickCheck
hidden-modules: Test.Hspec.Wai.Util Paths_hspec_wai
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-wai-0.9.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-wai-0.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hspec-wai-0.9.0
hs-libraries: HShspec-wai-0.9.0-9vBjdefcesqDA0TplrrZF8
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    hspec-core-2.5.5-8bOvLXMsNtaAUGCGhbw2og
    hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk
    http-types-0.12.1-II9Izt8nVfhCfceL6igA2T text-1.2.3.0
    transformers-0.5.5.0 wai-3.2.1.2-6InQkuIDpbKJzArdatehT8
    wai-extra-3.0.24.0-InvLOzg71G0IVeuYYdC3be
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             hspec-core-2.5.5-8bOvLXMsNtaAUGCGhbw2og=3ccb1c0f95ab08945910c24f3bef5232
             hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk=b75babfddd4aa9a267b9714ea3ac9e19
             http-types-0.12.1-II9Izt8nVfhCfceL6igA2T=b23e50a639b630c1d82e921bfca06775
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             wai-3.2.1.2-6InQkuIDpbKJzArdatehT8=97145bea61d3183ef9d5ecbcdf43df9c
             wai-extra-3.0.24.0-InvLOzg71G0IVeuYYdC3be=425a3858717a86bde44e6f2197607660
haddock-interfaces: /usr/share/doc/haskell-hspec-wai/html/hspec-wai.haddock
haddock-html: /usr/share/doc/haskell-hspec-wai/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
